/****************************************************************************
** Meta object code from reading C++ file 'k3bmovixdoc.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../k3b-26.08.0/libk3b/projects/movixcd/k3bmovixdoc.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'k3bmovixdoc.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3K3b8MovixDocE_t {};
} // unnamed namespace

template <> constexpr inline auto K3b::MovixDoc::qt_create_metaobjectdata<qt_meta_tag_ZN3K3b8MovixDocE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "K3b::MovixDoc",
        "itemsAboutToBeInserted",
        "",
        "pos",
        "count",
        "itemsInserted",
        "itemsAboutToBeRemoved",
        "itemsRemoved",
        "subTitleAboutToBeInserted",
        "K3b::MovixFileItem*",
        "parent",
        "subTitleInserted",
        "subTitleAboutToBeRemoved",
        "subTitleRemoved",
        "addUrls",
        "QList<QUrl>",
        "urls",
        "addUrlsAt",
        "addMovixItems",
        "QList<K3b::MovixFileItem*>&",
        "items",
        "removeMovixItem",
        "item",
        "moveMovixItem",
        "itemAfter",
        "addSubTitleItem",
        "QUrl",
        "removeSubTitleItem"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemsAboutToBeInserted'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'itemsInserted'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemsAboutToBeRemoved'
        QtMocHelpers::SignalData<void(int, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'itemsRemoved'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subTitleAboutToBeInserted'
        QtMocHelpers::SignalData<void(K3b::MovixFileItem *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'subTitleInserted'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subTitleAboutToBeRemoved'
        QtMocHelpers::SignalData<void(K3b::MovixFileItem *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'subTitleRemoved'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addUrls'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'addUrlsAt'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { QMetaType::Int, 3 },
        }}),
        // Slot 'addMovixItems'
        QtMocHelpers::SlotData<void(QList<K3b::MovixFileItem*> &, int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::Int, 3 },
        }}),
        // Slot 'addMovixItems'
        QtMocHelpers::SlotData<void(QList<K3b::MovixFileItem*> &)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'removeMovixItem'
        QtMocHelpers::SlotData<void(K3b::MovixFileItem *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 22 },
        }}),
        // Slot 'moveMovixItem'
        QtMocHelpers::SlotData<void(K3b::MovixFileItem *, K3b::MovixFileItem *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 22 }, { 0x80000000 | 9, 24 },
        }}),
        // Slot 'addSubTitleItem'
        QtMocHelpers::SlotData<void(K3b::MovixFileItem *, const QUrl &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 26, 2 },
        }}),
        // Slot 'removeSubTitleItem'
        QtMocHelpers::SlotData<void(K3b::MovixFileItem *)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MovixDoc, qt_meta_tag_ZN3K3b8MovixDocE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject K3b::MovixDoc::staticMetaObject = { {
    QMetaObject::SuperData::link<DataDoc::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b8MovixDocE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b8MovixDocE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3K3b8MovixDocE_t>.metaTypes,
    nullptr
} };

void K3b::MovixDoc::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MovixDoc *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemsAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->itemsInserted(); break;
        case 2: _t->itemsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->itemsRemoved(); break;
        case 4: _t->subTitleAboutToBeInserted((*reinterpret_cast<std::add_pointer_t<K3b::MovixFileItem*>>(_a[1]))); break;
        case 5: _t->subTitleInserted(); break;
        case 6: _t->subTitleAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<K3b::MovixFileItem*>>(_a[1]))); break;
        case 7: _t->subTitleRemoved(); break;
        case 8: _t->addUrls((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 9: _t->addUrlsAt((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->addMovixItems((*reinterpret_cast<std::add_pointer_t<QList<K3b::MovixFileItem*>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->addMovixItems((*reinterpret_cast<std::add_pointer_t<QList<K3b::MovixFileItem*>&>>(_a[1]))); break;
        case 12: _t->removeMovixItem((*reinterpret_cast<std::add_pointer_t<K3b::MovixFileItem*>>(_a[1]))); break;
        case 13: _t->moveMovixItem((*reinterpret_cast<std::add_pointer_t<K3b::MovixFileItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<K3b::MovixFileItem*>>(_a[2]))); break;
        case 14: _t->addSubTitleItem((*reinterpret_cast<std::add_pointer_t<K3b::MovixFileItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 15: _t->removeSubTitleItem((*reinterpret_cast<std::add_pointer_t<K3b::MovixFileItem*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MovixDoc::*)(int , int )>(_a, &MovixDoc::itemsAboutToBeInserted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MovixDoc::*)()>(_a, &MovixDoc::itemsInserted, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MovixDoc::*)(int , int )>(_a, &MovixDoc::itemsAboutToBeRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MovixDoc::*)()>(_a, &MovixDoc::itemsRemoved, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MovixDoc::*)(K3b::MovixFileItem * )>(_a, &MovixDoc::subTitleAboutToBeInserted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MovixDoc::*)()>(_a, &MovixDoc::subTitleInserted, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MovixDoc::*)(K3b::MovixFileItem * )>(_a, &MovixDoc::subTitleAboutToBeRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MovixDoc::*)()>(_a, &MovixDoc::subTitleRemoved, 7))
            return;
    }
}

const QMetaObject *K3b::MovixDoc::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *K3b::MovixDoc::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b8MovixDocE_t>.strings))
        return static_cast<void*>(this);
    return DataDoc::qt_metacast(_clname);
}

int K3b::MovixDoc::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DataDoc::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void K3b::MovixDoc::itemsAboutToBeInserted(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void K3b::MovixDoc::itemsInserted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void K3b::MovixDoc::itemsAboutToBeRemoved(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void K3b::MovixDoc::itemsRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void K3b::MovixDoc::subTitleAboutToBeInserted(K3b::MovixFileItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void K3b::MovixDoc::subTitleInserted()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void K3b::MovixDoc::subTitleAboutToBeRemoved(K3b::MovixFileItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void K3b::MovixDoc::subTitleRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
