/****************************************************************************
** Meta object code from reading C++ file 'k3bdvdcopyjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../k3b-26.08.0/libk3b/jobs/k3bdvdcopyjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'k3bdvdcopyjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3K3b10DvdCopyJobE_t {};
} // unnamed namespace

template <> constexpr inline auto K3b::DvdCopyJob::qt_create_metaobjectdata<qt_meta_tag_ZN3K3b10DvdCopyJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "K3b::DvdCopyJob",
        "start",
        "",
        "cancel",
        "setWriterDevice",
        "K3b::Device::Device*",
        "w",
        "setReaderDevice",
        "setImagePath",
        "p",
        "setRemoveImageFiles",
        "b",
        "setOnlyCreateImage",
        "setSimulate",
        "setOnTheFly",
        "setWriteSpeed",
        "s",
        "setCopies",
        "c",
        "setWritingMode",
        "WritingMode",
        "setIgnoreReadErrors",
        "setReadRetries",
        "i",
        "setVerifyData",
        "slotDiskInfoReady",
        "K3b::Device::DeviceHandler*",
        "slotReaderProgress",
        "slotReaderProcessedSize",
        "slotWriterProgress",
        "slotReaderFinished",
        "slotWriterFinished",
        "slotVerificationFinished",
        "slotVerificationProgress"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWriterDevice'
        QtMocHelpers::SlotData<void(K3b::Device::Device *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setReaderDevice'
        QtMocHelpers::SlotData<void(K3b::Device::Device *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setImagePath'
        QtMocHelpers::SlotData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'setRemoveImageFiles'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setOnlyCreateImage'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setSimulate'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setOnTheFly'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setWriteSpeed'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'setCopies'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'setWritingMode'
        QtMocHelpers::SlotData<void(WritingMode)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 6 },
        }}),
        // Slot 'setIgnoreReadErrors'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'setReadRetries'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'setVerifyData'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'slotDiskInfoReady'
        QtMocHelpers::SlotData<void(K3b::Device::DeviceHandler *)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Slot 'slotReaderProgress'
        QtMocHelpers::SlotData<void(int)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotReaderProcessedSize'
        QtMocHelpers::SlotData<void(int, int)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'slotWriterProgress'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotReaderFinished'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotWriterFinished'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotVerificationFinished'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotVerificationProgress'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DvdCopyJob, qt_meta_tag_ZN3K3b10DvdCopyJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject K3b::DvdCopyJob::staticMetaObject = { {
    QMetaObject::SuperData::link<BurnJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b10DvdCopyJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b10DvdCopyJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3K3b10DvdCopyJobE_t>.metaTypes,
    nullptr
} };

void K3b::DvdCopyJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DvdCopyJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->start(); break;
        case 1: _t->cancel(); break;
        case 2: _t->setWriterDevice((*reinterpret_cast<std::add_pointer_t<K3b::Device::Device*>>(_a[1]))); break;
        case 3: _t->setReaderDevice((*reinterpret_cast<std::add_pointer_t<K3b::Device::Device*>>(_a[1]))); break;
        case 4: _t->setImagePath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->setRemoveImageFiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->setOnlyCreateImage((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->setSimulate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->setOnTheFly((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setWriteSpeed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setCopies((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->setWritingMode((*reinterpret_cast<std::add_pointer_t<WritingMode>>(_a[1]))); break;
        case 12: _t->setIgnoreReadErrors((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->setReadRetries((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->setVerifyData((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->slotDiskInfoReady((*reinterpret_cast<std::add_pointer_t<K3b::Device::DeviceHandler*>>(_a[1]))); break;
        case 16: _t->slotReaderProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->slotReaderProcessedSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 18: _t->slotWriterProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->slotReaderFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->slotWriterFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->slotVerificationFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->slotVerificationProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *K3b::DvdCopyJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *K3b::DvdCopyJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b10DvdCopyJobE_t>.strings))
        return static_cast<void*>(this);
    return BurnJob::qt_metacast(_clname);
}

int K3b::DvdCopyJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BurnJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}
QT_WARNING_POP
