/****************************************************************************
** Meta object code from reading C++ file 'k3bffmpegdecoder.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../k3b-26.08.0/plugins/decoder/ffmpeg/k3bffmpegdecoder.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'k3bffmpegdecoder.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23K3bFFMpegDecoderFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto K3bFFMpegDecoderFactory::qt_create_metaobjectdata<qt_meta_tag_ZN23K3bFFMpegDecoderFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "K3bFFMpegDecoderFactory"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<K3bFFMpegDecoderFactory, qt_meta_tag_ZN23K3bFFMpegDecoderFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject K3bFFMpegDecoderFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<K3b::AudioDecoderFactory::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23K3bFFMpegDecoderFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23K3bFFMpegDecoderFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23K3bFFMpegDecoderFactoryE_t>.metaTypes,
    nullptr
} };

void K3bFFMpegDecoderFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<K3bFFMpegDecoderFactory *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *K3bFFMpegDecoderFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *K3bFFMpegDecoderFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23K3bFFMpegDecoderFactoryE_t>.strings))
        return static_cast<void*>(this);
    return K3b::AudioDecoderFactory::qt_metacast(_clname);
}

int K3bFFMpegDecoderFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = K3b::AudioDecoderFactory::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN16K3bFFMpegDecoderE_t {};
} // unnamed namespace

template <> constexpr inline auto K3bFFMpegDecoder::qt_create_metaobjectdata<qt_meta_tag_ZN16K3bFFMpegDecoderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "K3bFFMpegDecoder"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<K3bFFMpegDecoder, qt_meta_tag_ZN16K3bFFMpegDecoderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject K3bFFMpegDecoder::staticMetaObject = { {
    QMetaObject::SuperData::link<K3b::AudioDecoder::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16K3bFFMpegDecoderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16K3bFFMpegDecoderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16K3bFFMpegDecoderE_t>.metaTypes,
    nullptr
} };

void K3bFFMpegDecoder::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<K3bFFMpegDecoder *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *K3bFFMpegDecoder::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *K3bFFMpegDecoder::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16K3bFFMpegDecoderE_t>.strings))
        return static_cast<void*>(this);
    return K3b::AudioDecoder::qt_metacast(_clname);
}

int K3bFFMpegDecoder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = K3b::AudioDecoder::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
